@@ -24,7 +24,7 @@ class GeneratorGrid:
         Args:
             targets(dict): a list of targets
             a: the parent element
-            app: the parent spp
+            app: the parent app
             
         """
         self.gridRows=a
@@ -85,6 +85,8 @@ class GeneratorGrid:
         """
         react on the generate button having been clicked
         """
+        # force login 
+        self.app.smwAccess.wikiClient.login()
         cellsToGen=self.getCheckedYpCells()
         for ypCell in cellsToGen:
             try:
