@@ -123,6 +123,7 @@ topic links:"""
 """
         for prop in topic.properties.values():
             markup+=f"|?{topic.name} {prop.name} = {prop.name}\n"
+        markup+=f"| limit={topic.getListLimit()}\n"
         markup+=f"""{self.askSort(topic)}}}}}"""
         return markup
     
@@ -611,9 +612,10 @@ class PropertyTarget(SMWTarget):
 |documentation={prop.documentation}
 |type=Special:Types/{prop.type}
 """
+        # @TODO read from metamodel
         for prop_name in ["index","sortPos","primaryKey","mandatory",
            "namespace","size","uploadable","defaultValue","inputType",
-           "allowedValues","values_from","showInGrid","isLink"]:
+           "allowedValues","values_from","formatterURI","showInGrid","isLink"]:
             if hasattr(prop, prop_name):
                 value=getattr(prop,prop_name,None)
                 if value is not None:
@@ -622,7 +624,12 @@ class PropertyTarget(SMWTarget):
         markup+=f"""|topic={(topicWithConcept)}
 |storemode=prop       
 }}}}      
-[[Has type::{prop.type}]]
+* [[Has type::{prop.type}]]
+"""
+        if hasattr(prop, "formatterURI"):
+            markup+=f"""* External formatter uri: [[External formatter uri::{prop.formatterURI}]]
+"""
+        markup+=f"""
 This is a Property with type {{{{#show: {{{{FULLPAGENAMEE}}}} | ?Property type#- }}}}
 """
         return markup
@@ -632,6 +639,19 @@ class PythonTarget(SMWTarget):
     generator for Python Code for a Topic
     """
     
+    def pythonPropType(self,prop:Property)->str:
+        """
+        get the python property type for the given Property
+        """
+        ptype="str"
+        typestr=prop.type
+        typestr=typestr.replace("Types/","")
+        if typestr=="Boolean":
+            ptype="bool"
+        elif typestr=="Number":
+            ptype="float"
+        return ptype
+    
     def generate(self, topic:'Topic')->str:
         """
         generate python code for the given topic
@@ -648,7 +668,7 @@ class {topic.name}:
 '''
         
         for prop in topic.propertiesByIndex():
-            markup+=f'''    {prop.name}:Optional[str] # {getattr(prop,"documentation","")}\n'''
+            markup+=f'''    {prop.name}:Optional[{self.pythonPropType(prop)}] # {getattr(prop,"documentation","")}\n'''
         markup+=f'''
     @classmethod
     def askQuery(cls):
